==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebCalendarResourceStringsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCalendarResourceStringsDescription } from "./WebCalendarResourceStringsDescription";
/**
 * @hidden
 */
export let WebCalendarResourceStringsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebCalendarResourceStringsDescriptionMetadata extends Base {
        static b(a) {
            if (WebCalendarResourceStringsDescriptionMetadata.a == null) {
                WebCalendarResourceStringsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebCalendarResourceStringsDescriptionMetadata.c(WebCalendarResourceStringsDescriptionMetadata.a);
            }
            if (a.k(WebCalendarResourceStringsDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebCalendarResourceStringsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:CalendarResourceStrings");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("SelectMonth", "String");
            a.item("SelectYear", "String");
            a.item("SelectDate", "String");
            a.item("SelectRange", "String");
            a.item("SelectedDate", "String");
            a.item("StartDate", "String");
            a.item("EndDate", "String");
            a.item("PreviousMonth", "String");
            a.item("NextMonth", "String");
            a.item("PreviousYear", "String");
            a.item("NextYear", "String");
            a.item("PreviousYears", "String");
            a.item("NextYears", "String");
            a.item("WeekLabel", "String");
        }
        static d(a) {
            WebCalendarResourceStringsDescriptionMetadata.b(a);
            a.ad("WebCalendarResourceStrings", () => new WebCalendarResourceStringsDescription());
            a.ac("WebCalendarResourceStrings", WebCalendarResourceStringsDescriptionMetadata.a);
        }
    }
    WebCalendarResourceStringsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebCalendarResourceStringsDescriptionMetadata, 'WebCalendarResourceStringsDescriptionMetadata');
    WebCalendarResourceStringsDescriptionMetadata.a = null;
    return WebCalendarResourceStringsDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/WebCalendarResourceStringsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCalendarResourceStringsDescription } from "./WebCalendarResourceStringsDescription";
/**
 * @hidden
 */
export let WebCalendarResourceStringsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebCalendarResourceStringsDescriptionMetadata extends Base {
        static b(a) {
            if (WebCalendarResourceStringsDescriptionMetadata.a == null) {
                WebCalendarResourceStringsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebCalendarResourceStringsDescriptionMetadata.c(WebCalendarResourceStringsDescriptionMetadata.a);
            }
            if (a.k(WebCalendarResourceStringsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebCalendarResourceStringsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:CalendarResourceStrings");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__marshalByValue", "Boolean");
            a.item("SelectMonth", "String");
            a.item("SelectYear", "String");
            a.item("SelectDate", "String");
            a.item("SelectRange", "String");
            a.item("SelectedDate", "String");
            a.item("StartDate", "String");
            a.item("EndDate", "String");
            a.item("PreviousMonth", "String");
            a.item("NextMonth", "String");
            a.item("PreviousYear", "String");
            a.item("NextYear", "String");
            a.item("PreviousYears", "String");
            a.item("NextYears", "String");
            a.item("WeekLabel", "String");
        }
        static d(a) {
            WebCalendarResourceStringsDescriptionMetadata.b(a);
            a.ae("WebCalendarResourceStrings", () => new WebCalendarResourceStringsDescription());
            a.ad("WebCalendarResourceStrings", WebCalendarResourceStringsDescriptionMetadata.a);
        }
    }
    WebCalendarResourceStringsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebCalendarResourceStringsDescriptionMetadata, 'WebCalendarResourceStringsDescriptionMetadata');
    WebCalendarResourceStringsDescriptionMetadata.a = null;
    return WebCalendarResourceStringsDescriptionMetadata;
})();
